.. _pyromaths.outils.jinja2utils:

:mod:`jinja2utils` --- Utilitaires à utiliser avec les *templates* jinja2
=========================================================================

.. automodule:: pyromaths.outils.jinja2utils
    :members:
    :special-members:
    :undoc-members:
